/*
 * combinedtunecontroller.h
 * Copyright (C) 2006  Remko Troncon
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

#ifndef COMBINEDTUNECONTROLLER_H
#define COMBINEDTUNECONTROLLER_H

#include "tune.h"
#include "tunecontroller.h"

#include <QList>

class CombinedTuneController : public TuneController {
public:
    CombinedTuneController();
    ~CombinedTuneController();

    virtual Tune currentTune();

private:
    QList<TuneController *> controllers_;
};

#endif // COMBINEDTUNECONTROLLER_H
